Puput
=====

.. image:: https://img.shields.io/pypi/v/puput.svg
    :target: https://pypi.python.org/pypi/puput/

.. image:: https://travis-ci.org/APSL/puput.svg?branch=master
    :target: https://travis-ci.org/APSL/puput
    
.. image:: https://readthedocs.org/projects/puput/badge/?version=latest
    :target: https://readthedocs.org/projects/puput/?badge=latest
    
.. image:: https://api.codacy.com/project/badge/grade/f96e31ee1b8c4aa2b1402f12308afe96    
   :target: https://www.codacy.com/app/marctc/puput
   
Puput is a powerful and simple Django app to manage a blog. It uses the awesome `Wagtail CMS <https://github.com/torchbox/wagtail>`_ as content management system.

Puput is the catalan name for `Hoopoe <https://en.wikipedia.org/wiki/Hoopoe>`_ which is indeed a beautiful bird.

.. image:: http://i.imgur.com/3ByGQb6.png

Visit the `documentation <http://puput.readthedocs.org>`_ for an in-depth look at Puput.

Features
~~~~~~~~

* Built with Wagtail CMS and Django
* Inspired in Wordpress and Zinnia
* Simple & responsive HTML template by default
* SEO friendly urls
* Support for Disqus comments
* Entries by author, tags, categories, archives and search term
* Last & popular entries
* Configurable sidebar widgets
* RSS feeds
* Related entries
* Extensible entry model

.. image:: http://i.imgur.com/ndZLeWb.png

Examples of blog sites made with Puput
~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

* `Ncora Blog <https://www.ncora.com/blog/>`_
* `Ncora TV <https://www.ncora.com/tv/>`_
* `APSL <https://www.apsl.net/blog/>`_
* `Nautic Advisor <https://www.nauticadvisor.com/blog/>`_
* `Trespams <http://trespams.com/blog/>`_
* `Houm Hotels <http://www.houmhotels.com/blog/>`_
* `Body Therapy <http://bodytherapy.ru/blog/>`_
* `Loblolly <http://www.loblolly.io/blog/>`_

Setup
~~~~~

The setup process is explained `here <http://puput.readthedocs.io/en/latest/setup.html>`_.

Related repositories
~~~~~~~~~~~~~~~~~~~~
* `wordpress-to-puput <https://github.com/APSL/wordpress-to-puput/>`_: Import your Wordpress blog data into Puput.
* `blogger-to-puput <https://github.com/APSL/blogger-to-puput/>`_: Import your Blogger blog data into Puput.
* `zinnia-to-puput <https://github.com/APSL/zinnia-to-puput/>`_:  Import your Zinnia blog data into Puput.   
* `docker-puput <https://github.com/APSL/docker-puput/>`_:  Docker image for Puput blog.
* `puput-demo <https://github.com/APSL/puput-demo/>`_: An example of blog Django app using Puput.
* `divio-wagtail-puput <https://github.com/divio/divio-wagtail-puput/>`_: A Divio Cloud addon to install the Wagtail Puput weblog.

